//========================================================================
//
// about-text.h
//
// Copyright 2002-2007 Glyph & Cog, LLC
//
//========================================================================

static char *aboutWinText[] = {
  "http://www.foolabs.com/xpdf/",
  "derekn@foolabs.com",
  " ",
  "Licensed under the GNU General Public License (GPL).",
  "See the 'COPYING' file for details.",
  " ",
  "Supports PDF version " supportedPDFVersionStr ".",
  " ",
  "The PDF data structures, operators, and specification",
  "are copyright 1985-2006 Adobe Systems Inc.",
  " ",
  "Mouse bindings:",
  "  button 1: select text / follow link",
  "  button 2: pan window",
  "  button 3: menu",
  " ",
  "Key bindings:",
  "  o              = open file",
  "  r              = reload",
  "  f / ctrl-F     = find text",
  "  ctrl-G         = find next",
  "  ctrl-P         = print",
  "  n              = next page",
  "  p              = previous page",
  "  <PgDn> = <space>                = scroll down",
  "  <PgUp> = <backspace> = <delete> = scroll up",
  "  v              = forward (history path)",
  "  b              = backward (history path)",
  "  0 / + / -      = zoom zero / in / out",
  "  z / w          = zoom page / page width",
  "  alt-F          = toggle full-screen mode",
  "  ctrl-L         = redraw",
  "  q              = quit",
  "  <home> / <end> = top / bottom of page",
  "  <arrows>       = scroll",
  " ",
  "For more information, please read the xpdf(1) man page.",
  NULL
};
